@@ -5,12 +5,14 @@ from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
+
 from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
     Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
 from tkdev.devcore import DevAction, DevSysTray
 from tkdev.devdraw import DrawButton
 from tkdev.devpre import DevPreToolbox
+from tkdev.winico import DevTray, WM_EVENT, download_winico
 import warnings
 
 try:
@@ -242,6 +244,10 @@ def dwm_set_window_attribute(window: tk.Tk, attribute, value):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), attribute, value)
 
 
+def sendmessage(window: tk.Tk, command, ofter, num):
+    SendMessage(GetParent(window.winfo_id()), command, ofter, num)
+
+
 def window_move(widget: tk.Widget, window: tk.Tk):
     """
     用于拖动窗口，widget为使窗口移动的组件，window为被移动的窗口
@@ -677,9 +683,10 @@ class DevDocs(tk.PanedWindow):
 
 
 class DevExtend(tk.Frame):
-    def __init__(self, master: tk.Widget, label: tk.Widget = tk.Label, text: str = "", widget: tk.Widget = tk.Message):
+    def __init__(self, master: tk.Widget, label: tk.Widget = None, text: str = "", widget: tk.Widget = tk.Message):
         super(DevExtend, self).__init__(master=master)
-        self.label = label
+        if label is None:
+            self.label = tk.Label()
         self.text = text
         self.widget = widget
 
@@ -961,48 +968,6 @@ class DevStatusBar(tk.Frame):
         self.pack(fill=tk.X, side=tk.BOTTOM)
 
 
-class DevSubWindow(tk.Frame):
-    def __init__(self, master, title_label: str = "Title", background="white", resize_size: int = 10,
-                 button_side=tk.RIGHT,
-                 titlebar_background="white",
-                 close: bool = True, max: bool = True, min: bool = True, title: bool = True,
-                 title_bg="#ffffff", title_fg="#000000",
-                 close_bg="#ffffff", max_bg="#ffffff", min_bg="#ffffff", close_func=None,
-                 close_active_bg="#e81123", close_active_fg="#f5f5f5", max_active_bg="#c2c2c2", max_active_fg="#ffffff",
-                 min_active_bg="#c2c2c2", min_active_fg="#ffffff",
-                 close_fg="#000000", max_fg="#000000", min_fg="#000000"):
-        """
-        实现了子窗口的功能，在tkinter中没有子窗口，我终于研究成功了。他是个框架，你可以将他使用pack、place进行显示
-
-        :param master:
-        :param title:
-        :param background:
-        :param titlebar_background:
-        :param titlebar_foreground:
-        """
-        super(DevSubWindow, self).__init__(master=master, background=background, borderwidth=1, relief=tk.RIDGE)
-        self.titlebar = DevTitleBar(master=self, iswindow=False, widget=self, button_side=button_side,
-                                    background=titlebar_background,
-                                    close=close, max=max, min=min, title=title, title_label=title_label,
-                                    title_bg=title_bg, title_fg=title_fg,
-                                    close_bg=close_bg, max_bg=max_bg, min_bg=min_bg, close_func=None,
-                                    close_active_bg=close_active_bg, close_active_fg=close_active_fg,
-                                    max_active_bg=max_active_bg,
-                                    max_active_fg=max_active_fg, min_active_bg=min_active_bg,
-                                    min_active_fg=min_active_fg,
-                                    close_fg=close_fg, max_fg=max_fg, min_fg=min_fg)
-        self.titlebar.pack(fill=tk.X, side=tk.TOP)
-        self.bind("Configure", DevResize)
-        resize_widget(self, size=resize_size)
-        self.update()
-
-    def set_titlebar(self, titlebar):
-        self.titlebar = titlebar
-
-    def show(self):
-        self.place(x=0, y=0, width=300, height=300)
-
-
 class DevToast(tk.Toplevel):
     def __init__(self, master: tk.Tk = None,
                  title: str = "Title", message: str = "Message", height: int = 80):
@@ -1291,4 +1256,5 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    Install_ALL()
+    Window = DevWindow()
+    Window.mainloop()
